==> switchyard-quickstart-distro-0.5.0.Beta1.zip: rules-camel-cbr/src/main/java/org/switchyard/quickstarts/rules/camel/cbr/BlueServiceBean.java <==
/* 
 * JBoss, Home of Professional Open Source 
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved. 
 * See the copyright.txt in the distribution for a 
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use, 
 * modify, copy, or redistribute it subject to the terms and conditions 
 * of the GNU Lesser General Public License, v. 2.1. 
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details. 
 * You should have received a copy of the GNU Lesser General Public License, 
 * v.2.1 along with this distribution; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 */
package org.switchyard.quickstarts.rules.camel.cbr;

import org.apache.log4j.Logger;
import org.switchyard.component.bean.Service;

/**
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; (C) 2011 Red Hat Inc.
 */
@Service(BlueService.class)
public class BlueServiceBean implements BlueService {

    private static final Logger LOGGER = Logger.getLogger(BlueServiceBean.class);
 
    @Override
    public void handleBlue(Widget widget) {
        LOGGER.info("Blue service processing widget with id: " + widget.getId());
    }

}

==> switchyard-quickstart-distro-0.6.0.Beta1.zip: rules-camel-cbr/src/main/java/org/switchyard/quickstarts/rules/camel/cbr/BlueServiceBean.java <==
/* 
 * JBoss, Home of Professional Open Source 
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved. 
 * See the copyright.txt in the distribution for a 
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use, 
 * modify, copy, or redistribute it subject to the terms and conditions 
 * of the GNU Lesser General Public License, v. 2.1. 
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details. 
 * You should have received a copy of the GNU Lesser General Public License, 
 * v.2.1 along with this distribution; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 */
package org.switchyard.quickstarts.rules.camel.cbr;

import org.apache.log4j.Logger;
import org.switchyard.component.bean.Service;

/**
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; (C) 2011 Red Hat Inc.
 */
@Service(BlueService.class)
public class BlueServiceBean implements BlueService {

    private static final Logger LOGGER = Logger.getLogger(BlueServiceBean.class);
 
    @Override
    public void handleBlue(Box box) {
        LOGGER.info("Blue service processing boxed widget with id: " + box.getWidget().getId());
    }

}
